# -----------------------------------------------------------------------
# This file produces the appendix results. 
# -----------------------------------------------------------------------

# -----------------------------------------------------------------------
# Loading the functions
# -----------------------------------------------------------------------
rm(list=ls())
getwd()
# require(data.table)
require(lme4)
require(foreign)
require(dplyr)
require(stargazer)
set.seed(1234)
source("./R-functions.R")

mi.extract <- function(model,im.dat,mfx = F,
                       effect = "",moderator = "",num_points = 10,
                       boot=F,subst="ALL") {
  if(subst == "ALL") {
    subst <- lapply(1:length(im.dat), function(x) 1:nrow(im.dat[[x]]))
  }
  
  if(boot) {
    mods <- sapply(1:length(im.dat), function(d) lmer(as.formula(model),data = im.dat[[d]][sample(1:nrow(im.dat[[d]]),replace = T),]))
  } else {
    mods <- sapply(1:length(im.dat), function(d) lmer(as.formula(model),data = im.dat[[d]],subset = subst[[d]]))
  }
  
  mfx.res <- NULL
  if(mfx) {
    delta <- apply(sapply(mods,function(m) interaction_plot_continuous(m,effect = effect,moderator = moderator,plot = F,num_points = num_points)$delta_1),1,mean)
    X_2 <- apply(sapply(mods,function(m) interaction_plot_continuous(m,effect = effect,moderator = moderator,plot = F,num_points = num_points)$x_2),1,mean)
    lb <- apply(sapply(mods,function(m) interaction_plot_continuous(m,effect = effect,moderator = moderator,plot = F,num_points = num_points)$lb),1,mean)
    ub <- apply(sapply(mods,function(m) interaction_plot_continuous(m,effect = effect,moderator = moderator,plot = F,num_points = num_points)$ub),1,mean)
    mfx.res <- cbind(delta,X_2,lb,ub)
  }
  
  coefs <- sapply(mods, function(m) summary(m)$coef[,1])
  ses <- sapply(mods,function(m) summary(m)$coef[,2])
  
  Q <- apply(coefs,1,mean)
  U <- apply(ses^2,1,mean)
  B <- apply((coefs - Q)^2,1,sum)/(ncol(coefs)-1)
  var <- U + (1 + 1/ncol(coefs))*B
  nu <- (ncol(coefs) - 1)*(1 + U/((1 + 1/ncol(coefs))*B))^2
  
  coef.table <- matrix(NA, nrow = nrow(coefs), ncol = 4)
  dimnames(coef.table) <- list(rownames(coefs),
                               c("Value", "Std. Error", "t-stat", "p-value"))
  coef.table[,1] <- Q
  coef.table[,2] <- sqrt(var)
  coef.table[,3] <- Q/sqrt(var)
  coef.table[,4] <- pt(abs(Q/sqrt(var)), df=nu, lower.tail=F)*2
  return(list(coef.table,mfx.res))
}

# -----------------------------------------------------------------------
# Loading the data
# -----------------------------------------------------------------------
load("./bhrvDAT.RData")

# -----------------------------------------------------------------------
# Appendices Results
# -----------------------------------------------------------------------
# Dropping 10% at random
mdg.coef <- NA
trans.coef <- NA
dem.coef <- NA
for(i in 1:1000) {
  subst <- lapply(1:length(dat.am$imputations), function(x) 
    which(runif(nrow(dat.am$imputations[[x]]),0,1) > .1))
  
  temp <- mi.extract(paste("primadjdiff ~ mdg*(scale(transparencyindex) + democracy) + 
                               scale(log((AID_Total_lag/pop)+1)) + 
                           scale(log((AID_Primary_education_lag/pop)+1)) + 
                           scale(log((AID_Secondary_education_lag/pop)+1)) + 
                           rgdpch + primadjlag + (1|year) + (1|wdicode)",sep=""),
                     dat.am$imputations,subst = subst)[[1]]
  mdg.coef[i] <- temp["mdg",1]
  trans.coef[i] <- temp["mdg:scale(transparencyindex)",1]
  dem.coef[i] <- temp["mdg:democracy",1]
  cat(paste(i,"\n",sep=""))
}

mdg.dens <- density(mdg.coef,bw = .0075)
trans.dens <- density(trans.coef,bw = .0075)
dem.dens <- density(dem.coef,bw = .0075)
pdf("./Figures/robust-10pct-primary.pdf",width=5,height=5)
plot(mdg.dens,main="Primary Robustness: Dropping 10%",type='n',xlab="Coefficients",
     xlim=c(-.1,.2),ylim=c(0,50))
polygon(mdg.dens,lty = 1,col = "white")
polygon(trans.dens,col=rgb(0,0,0,.5),lty = 2)
polygon(dem.dens,col=rgb(0,0,0,.1),lty = 3)
abline(v=0,lty=2)
legend("topright",legend=c("MDG","x Trans","x Dem"),
       fill=c("white",rgb(0,0,0,.5),rgb(0,0,0,.1)),lty=c(1,2,3))
dev.off()

mdg.coef <- NA
trans.coef <- NA
dem.coef <- NA
for(i in 1:1000) {
  subst <- lapply(1:length(dat.am$imputations), function(x) 
    which(runif(nrow(dat.am$imputations[[x]]),0,1) > .1))
  
  temp <- mi.extract(paste("secdiff ~ mdg*(scale(transparencyindex) + democracy) + 
                              scale(log((AID_Total_lag/pop)+1)) + 
                           scale(log((AID_Primary_education_lag/pop)+1)) + 
                           scale(log((AID_Secondary_education_lag/pop)+1)) + 
                           rgdpch + trend + seclag + (1|year) + (1|wdicode)",sep=""),
                     dat.am$imputations,subst = subst)[[1]]
  mdg.coef[i] <- temp["mdg",1]
  trans.coef[i] <- temp["mdg:scale(transparencyindex)",1]
  dem.coef[i] <- temp["mdg:democracy",1]
  cat(paste(i,"\n",sep=""))
}

mdg.dens <- density(mdg.coef,bw = .00075)
trans.dens <- density(trans.coef,bw = .00075)
dem.dens <- density(dem.coef,bw = .00075)
pdf("./Figures/robust-10pct-secter.pdf",width=5,height=5)
plot(mdg.dens,main="Secondary Robustness: Dropping 10%",type='n',xlab="Coefficients",
     xlim=c(-.01,.02),ylim=c(0,695))
polygon(mdg.dens,lty = 1,col = "white")
polygon(trans.dens,col=rgb(0,0,0,.5),lty = 2)
polygon(dem.dens,col=rgb(0,0,0,.1),lty = 3)
abline(v=0,lty=2)
legend("topright",legend=c("MDG","x Trans","x Dem"),
       fill=c("white",rgb(0,0,0,.5),rgb(0,0,0,.1)),lty=c(1,2,3))
dev.off()

# Dropping one country at a time
mdg.coef <- NA
trans.coef <- NA
dem.coef <- NA
cntries <- unique(dat.am$imputations$imp1$country)
for(i in 1:length(cntries)) {
  subst <- lapply(1:length(dat.am$imputations), function(x) 
    which(dat.am$imputations[[x]]$country != cntries[i]))
  
  temp <- mi.extract(paste("primadjdiff ~ mdg*(scale(transparencyindex) + democracy) + 
                           scale(log((AID_Total_lag/pop)+1)) + 
                           scale(log((AID_Primary_education_lag/pop)+1)) + 
                           scale(log((AID_Secondary_education_lag/pop)+1)) + 
                           rgdpch + primadjlag + (1|year) + (1|wdicode)",sep=""),
                     dat.am$imputations,subst = subst)[[1]]
  mdg.coef[i] <- temp["mdg",1]
  trans.coef[i] <- temp["mdg:scale(transparencyindex)",1]
  dem.coef[i] <- temp["mdg:democracy",1]
  cat(paste(i,"\n",sep=""))
}

mdg.dens <- density(mdg.coef,bw = .0075)
trans.dens <- density(trans.coef,bw = .0075)
dem.dens <- density(dem.coef,bw = .0075)
pdf("./Figures/robust-cntry-beta.pdf",width=7,height=5)
plot(mdg.dens,main="Primary Robustness: Dropping One Country",type='n',xlab="Coefficients",
     xlim=c(-.06,.15),ylim=c(0,100))
polygon(mdg.dens,lty = 1,col = "white")
polygon(trans.dens,col=rgb(0,0,0,.5),lty = 2)
polygon(dem.dens,col=rgb(0,0,0,.1),lty = 3)
abline(v=0,lty=2)
legend("topright",legend=c("MDG","x Trans","x Dem"),
       fill=c("white",rgb(0,0,0,.5),rgb(0,0,0,.1)),lty=c(1,2,3))
dev.off()


# Subsets of wealth (lt $1000)
mdg.coef <- NA
trans.coef <- NA
dem.coef <- NA
for(i in 1:1000) {
  subst <- lapply(1:length(dat.am$imputations), function(x) 
    which(dat.am$imputations[[x]]$gdppc.2000 < 1000 & runif(nrow(dat.am$imputations[[x]]),0,1) > .1))
  
  temp <- mi.extract(paste("primadjdiff ~ mdg*(scale(transparencyindex) + democracy) + 
                           scale(log((AID_Total_lag/pop)+1)) + 
                           scale(log((AID_Primary_education_lag/pop)+1)) + 
                           scale(log((AID_Secondary_education_lag/pop)+1)) + 
                           rgdpch + primadjlag + (1|year) + (1|wdicode)",sep=""),
                     dat.am$imputations,subst = subst)[[1]]
  mdg.coef[i] <- temp["mdg",1]
  trans.coef[i] <- temp["mdg:scale(transparencyindex)",1]
  dem.coef[i] <- temp["mdg:democracy",1]
  cat(paste(i,"\n",sep=""))
}

mdg.dens <- density(mdg.coef,bw = .0075)
trans.dens <- density(trans.coef,bw = .0075)
dem.dens <- density(dem.coef,bw = .0075)
pdf("./Figures/robust-10pct-primary-1000.pdf",width=5,height=5)
plot(mdg.dens,main="Primary Robustness Among GDPpc < $1,000:\n Dropping 10%",type='n',xlab="Coefficients",
     xlim=c(-.1,.3),ylim=c(0,60))
polygon(mdg.dens,lty = 1,col = "white")
polygon(trans.dens,col=rgb(0,0,0,.5),lty = 2)
polygon(dem.dens,col=rgb(0,0,0,.1),lty = 3)
abline(v=0,lty=2)
legend("topright",legend=c("MDG","x Trans","x Dem"),
       fill=c("white",rgb(0,0,0,.5),rgb(0,0,0,.1)),lty=c(1,2,3))
dev.off()

mdg.coef <- NA
trans.coef <- NA
dem.coef <- NA
for(i in 1:1000) {
  subst <- lapply(1:length(dat.am$imputations), function(x) 
    which(dat.am$imputations[[x]]$gdppc.2000 < 13000 & runif(nrow(dat.am$imputations[[x]]),0,1) > .1))
  
  temp <- mi.extract(paste("primadjdiff ~ mdg*(scale(transparencyindex) + democracy) + 
                           scale(log((AID_Total_lag/pop)+1)) + 
                           scale(log((AID_Primary_education_lag/pop)+1)) + 
                           scale(log((AID_Secondary_education_lag/pop)+1)) + 
                           rgdpch + primadjlag + (1|year) + (1|wdicode)",sep=""),
                     dat.am$imputations,subst = subst)[[1]]
  mdg.coef[i] <- temp["mdg",1]
  trans.coef[i] <- temp["mdg:scale(transparencyindex)",1]
  dem.coef[i] <- temp["mdg:democracy",1]
  cat(paste(i,"\n",sep=""))
}

mdg.dens <- density(mdg.coef,bw = .0075)
trans.dens <- density(trans.coef,bw = .0075)
dem.dens <- density(dem.coef,bw = .0075)
pdf("./Figures/robust-10pct-primary-13000.pdf",width=5,height=5)
plot(mdg.dens,main="Primary Robustness Among GDPpc < $13,000:\n Dropping 10%",type='n',xlab="Coefficients",
     xlim=c(-.15,.2),ylim=c(0,50))
polygon(mdg.dens,lty = 1,col = "white")
polygon(trans.dens,col=rgb(0,0,0,.5),lty = 2)
polygon(dem.dens,col=rgb(0,0,0,.1),lty = 3)
abline(v=0,lty=2)
legend("topright",legend=c("MDG","x Trans","x Dem"),
       fill=c("white",rgb(0,0,0,.5),rgb(0,0,0,.1)),lty=c(1,2,3))
dev.off()





# VAR analysis: These plots are constructed using the output from the Stata file "var-work.do"
tmp <- dat.am$imputations$imp1 %>% select(wdicode,year,mdg,primadj,secadj,primary,secter,transparencyindex,primraw,secraw,democracy,gdppc,gdppc.2000)
tmp2 <- dat.am$imputations$imp2 %>% select(wdicode,year,mdg,primadj,secadj,primary,secter,transparencyindex,primraw,secraw,democracy,gdppc,gdppc.2000)
tmp3 <- dat.am$imputations$imp3 %>% select(wdicode,year,mdg,primadj,secadj,primary,secter,transparencyindex,primraw,secraw,democracy,gdppc,gdppc.2000)
tmp4 <- dat.am$imputations$imp4 %>% select(wdicode,year,mdg,primadj,secadj,primary,secter,transparencyindex,primraw,secraw,democracy,gdppc,gdppc.2000)
tmp5 <- dat.am$imputations$imp5 %>% select(wdicode,year,mdg,primadj,secadj,primary,secter,transparencyindex,primraw,secraw,democracy,gdppc,gdppc.2000)
avg.dat <- tmp
cols <- sapply(colnames(tmp), function(x) all(tmp[[x]] == tmp2[[x]]))

for(c in names(cols[which(!cols)])) {
  avg.dat$tmp <- rowMeans(cbind(tmp[[c]],
                                tmp2[[c]],
                                tmp3[[c]],
                                tmp4[[c]],
                                tmp5[[c]]),na.rm = T)
  avg.dat <- avg.dat[,which(colnames(avg.dat) != c)]
  colnames(avg.dat)[which(colnames(avg.dat) == "tmp")] <- c
}
colnames(avg.dat) <- gsub("\\.","_",colnames(avg.dat))
require(haven)
write_dta(avg.dat,"./dat-mix.dta",version = 12) # Saving for analysis with the xtvar program in Stata

# -----------------------------------------------------------------------
# 3.b: Impule response visualization
# -----------------------------------------------------------------------
dat <- read_dta("./xtvar-comb-4.dta")
keeps <- c(paste("D0",2,sep=""),paste("pD0",2,"_ll",sep=""),paste("pD0",2,"_ul",sep=""))
dat.p <- dat[,which(colnames(dat)%in%keeps)]
keeps <- c(paste("D0",3,sep=""),paste("pD0",3,"_ll",sep=""),paste("pD0",3,"_ul",sep=""))
dat.s <- dat[,which(colnames(dat) %in% keeps)]

pdf("./Figures/var2.pdf",width = 6,height = 6)
center <- dat.p$D02[1]
abs <- max(abs(min(dat.p[,2])),abs(max(dat.p[,3])))
mins <- center - abs
maxs <- center + abs
par(mar=c(5,5,3,5))
plot(0:30,dat.p$D02,xlim=c(-1,31),ylim=c(mins,maxs),main=paste("Impulse: MDG",sep=""),
     ylab="Impact on Primary Enrollment",xlab="Time",yaxt='n',xaxs="i",bty = 'n')
axis(2,at=seq(mins,maxs,length.out=7),labels=round(seq(mins,maxs,length.out=7),3),las=2,cex.axis = .7)
segments(0:30,dat.p$pD02_ll,0:30,dat.p$pD02_ul)
points(0:30,dat.p$D02,pch = 21,bg = "white")
abline(h=dat.p$D02[1],lty=3,col=rgb(0,0,0,.1))

par(new=T)
center <- dat.s$D03[1]
abs <- max(abs(min(dat.s[,2])),abs(max(dat.s[,3])))
mins <- center - abs
maxs <- center + abs
plot(0:30,dat.s$D03,xlim=c(-1,31),type = 'n',ylim=c(mins,maxs),
     main="",ylab="",xlab="",xaxs='i',yaxt='n',bty = 'n')
axis(4,at=seq(mins,maxs,length.out=7),labels=round(seq(mins,maxs,length.out=7),3),las=2,cex.axis = .7)
mtext("Impact on Secondary Enrollment",side = 4,line = 3,srt = 180)
points(0:30,dat.s$D03,pch = 21,bg = "black")
segments(0:30,dat.s$pD03_ll,0:30,dat.s$pD03_ul)
legend("bottomleft",legend = c("Primary","Secondary"),pch = 21,pt.bg = c("white","black"),cex = .8,bty = 'n')
dev.off()




# RDD Analysis
require(KernSmooth)
range01 <- function(x){(x-min(x))/(max(x)-min(x))}

avg.dat <- as.data.frame(avg.dat)
avg.dat$prm <- scale(avg.dat$primary)
avg.dat$prmscale <- range01(avg.dat$prm)

yrbins <- NA
cuts <- seq(1980,2010,by=4)
for(j in 1:length(cuts)) {
  yrbins[j] <- mean(avg.dat[which(avg.dat$year >= cuts[j] & avg.dat$year < cuts[j+1]),"prmscale"],na.rm=T)
}
yrbins[length(cuts)] <- mean(avg.dat[which(avg.dat$year >= cuts[j-1] & avg.dat$year < cuts[j]),"prmscale"])

loclpolCreate <- function(dat,x = "year",y = "prmscale",tstat = 1.65,xrange = 1980:2000) {
  mean <- with(dat,locpoly(get(x),get(y),bandwidth = 1,gridsize = length(xrange)))$y
  se <- predict(loess(get(y) ~ get(x), dat),se = T)$se*tstat
  res <- data.frame("mean" = mean,"se" = se,"x" = xrange)
  return(res)
}

mainlocpol.pre <- array(NA,dim=c(length(unique(avg.dat$wdicode)),length(1980:2000)))
mainlocpol.prese <- array(NA,dim=c(length(unique(avg.dat$wdicode)),length(1980:2000)))
mainlocpol.post <- array(NA,dim=c(length(unique(avg.dat$wdicode)),length(2000:2010)))
mainlocpol.postse <- array(NA,dim=c(length(unique(avg.dat$wdicode)),length(2000:2010)))
i = 1
for(j in unique(avg.dat$wdicode)) {
  tmp <- loclpolCreate(dat = avg.dat[which(avg.dat$year <= 2000 & avg.dat$wdicode == j),],xrange = 1980:2000)
  mainlocpol.pre[i,] <- tmp$mean
  mainlocpol.prese[i,] <- tmp$se
  tmp <- loclpolCreate(dat = avg.dat[which(avg.dat$year >= 2000 & avg.dat$wdicode == j),],xrange = 2000:2010)
  mainlocpol.post[i,] <- tmp$mean
  mainlocpol.postse[i,] <- tmp$se
  i = i+1
}


xax.pre <- with(avg.dat[which(avg.dat$year <= 2000 & avg.dat$wdicode == j),],locpoly(year,prmscale,bandwidth = 5))$x
xax.post <- with(avg.dat[which(avg.dat$year >= 2000 & avg.dat$wdicode == j),],locpoly(year,prmscale,bandwidth = 5))$x

avg.dat$flag13k <- ifelse(avg.dat$gdppc_2000 <= 13000,1,0)
dat.13k <- avg.dat[which(avg.dat$flag13k == 1),]
lp13k.pre <- array(NA,dim=c(length(unique(dat.13k$wdicode)),length(1980:2000)))
lp13k.prese <- array(NA,dim=c(length(unique(dat.13k$wdicode)),length(1980:2000)))
lp13k.post <- array(NA,dim=c(length(unique(dat.13k$wdicode)),length(2000:2010)))
lp13k.postse <- array(NA,dim=c(length(unique(dat.13k$wdicode)),length(2000:2010)))
i = 1
for(j in unique(dat.13k$wdicode)) {
  tmp <- loclpolCreate(dat = dat.13k[which(dat.13k$year <= 2000 & dat.13k$wdicode == j),],
                       xrange = 1980:2000)
  lp13k.pre[i,] <- tmp$mean
  lp13k.prese[i,] <- tmp$se
  tmp <- loclpolCreate(dat = dat.13k[which(dat.13k$year >= 2000 & dat.13k$wdicode == j),],
                       xrange = 2000:2010)
  lp13k.post[i,] <- tmp$mean
  lp13k.postse[i,] <- tmp$se
  i = i+1
}

avg.dat$flag1k <- ifelse(avg.dat$gdppc_2000 <= 1000,1,0)
dat.1k <- avg.dat[which(avg.dat$flag1k == 1),]
lp1k.pre <- array(NA,dim=c(length(unique(dat.1k$wdicode)),length(1980:2000)))
lp1k.prese <- array(NA,dim=c(length(unique(dat.1k$wdicode)),length(1980:2000)))
lp1k.post <- array(NA,dim=c(length(unique(dat.1k$wdicode)),length(2000:2010)))
lp1k.postse <- array(NA,dim=c(length(unique(dat.1k$wdicode)),length(2000:2010)))
i = 1
for(j in unique(dat.1k$wdicode)) {
  tmp <- loclpolCreate(dat = dat.1k[which(dat.1k$year <= 2000 & dat.1k$wdicode == j),],
                       xrange = 1980:2000)
  lp1k.pre[i,] <- tmp$mean
  lp1k.prese[i,] <- tmp$se
  tmp <- loclpolCreate(dat = dat.1k[which(dat.1k$year >= 2000 & dat.1k$wdicode == j),],
                       xrange = 2000:2010)
  lp1k.post[i,] <- tmp$mean
  lp1k.postse[i,] <- tmp$se
  i = i+1
}

avg.dat$meanprm <- sapply(unique(avg.dat$wdicode), function(x) mean(avg.dat[which(avg.dat$wdicode == x),"primraw"],na.rm=T))
for(i in unique(avg.dat$wdicode)) {
  avg.dat[which(avg.dat$wdicode == i),"meanprm"] <- avg.dat[which(avg.dat$wdicode == i),"primraw"][1]
}

avg.dat$flaglow <- ifelse(avg.dat$meanprm <= quantile(avg.dat$meanprm,.25),1,0)
dat.low <- avg.dat[which(avg.dat$flaglow == 1),]
lplow.pre <- array(NA,dim=c(length(unique(dat.low$wdicode)),length(1980:2000)))
lplow.prese <- array(NA,dim=c(length(unique(dat.low$wdicode)),length(1980:2000)))
lplow.post <- array(NA,dim=c(length(unique(dat.low$wdicode)),length(2000:2010)))
lplow.postse <- array(NA,dim=c(length(unique(dat.low$wdicode)),length(2000:2010)))
i = 1
for(j in unique(dat.low$wdicode)) {
  tmp <- loclpolCreate(dat = dat.low[which(dat.low$year <= 2000 & dat.low$wdicode == j),],
                       xrange = 1980:2000)
  lplow.pre[i,] <- tmp$mean
  lplow.prese[i,] <- tmp$se
  tmp <- loclpolCreate(dat = dat.low[which(dat.low$year >= 2000 & dat.low$wdicode == j),],
                       xrange = 2000:2010)
  lplow.post[i,] <- tmp$mean
  lplow.postse[i,] <- tmp$se
  i = i+1
}
avg.dat$flaghigh <- ifelse(avg.dat$meanprm >= quantile(avg.dat$meanprm,.75),1,0)
dat.high <- avg.dat[which(avg.dat$flaghigh == 1),]
lphigh.pre <- array(NA,dim=c(length(unique(dat.high$wdicode)),length(1980:2000)))
lphigh.prese <- array(NA,dim=c(length(unique(dat.high$wdicode)),length(1980:2000)))
lphigh.post <- array(NA,dim=c(length(unique(dat.high$wdicode)),length(2000:2010)))
lphigh.postse <- array(NA,dim=c(length(unique(dat.high$wdicode)),length(2000:2010)))
i = 1
for(j in unique(dat.high$wdicode)) {
  tmp <- loclpolCreate(dat = dat.high[which(dat.high$year <= 2000 & dat.high$wdicode == j),],
                       xrange = 1980:2000)
  lphigh.pre[i,] <- tmp$mean
  lphigh.prese[i,] <- tmp$se
  tmp <- loclpolCreate(dat = dat.high[which(dat.high$year >= 2000 & dat.high$wdicode == j),],
                       xrange = 2000:2010)
  lphigh.post[i,] <- tmp$mean
  lphigh.postse[i,] <- tmp$se
  i = i+1
}

avg.dat$meantrns <- sapply(unique(avg.dat$wdicode), function(x) mean(avg.dat[which(avg.dat$wdicode == x),"transparencyindex"],na.rm=T))
for(i in unique(avg.dat$wdicode)) {
  avg.dat[which(avg.dat$wdicode == i),"meantrns"] <- mean(avg.dat[which(avg.dat$wdicode == i),"transparencyindex"],na.rm=T)
}

avg.dat$flagtrns <- ifelse(avg.dat$meantrns <= quantile(avg.dat$meantrns,.5),1,0)
dat.trns <- avg.dat[which(avg.dat$flagtrns == 1),]
lptrns.pre <- array(NA,dim=c(length(unique(dat.trns$wdicode)),length(1980:2000)))
lptrns.prese <- array(NA,dim=c(length(unique(dat.trns$wdicode)),length(1980:2000)))
lptrns.post <- array(NA,dim=c(length(unique(dat.trns$wdicode)),length(2000:2010)))
lptrns.postse <- array(NA,dim=c(length(unique(dat.trns$wdicode)),length(2000:2010)))
i = 1
for(j in unique(dat.trns$wdicode)) {
  tmp <- loclpolCreate(dat = dat.trns[which(dat.trns$year <= 2000 & dat.trns$wdicode == j),],
                       xrange = 1980:2000)
  lptrns.pre[i,] <- tmp$mean
  lptrns.prese[i,] <- tmp$se
  tmp <- loclpolCreate(dat = dat.trns[which(dat.trns$year >= 2000 & dat.trns$wdicode == j),],
                       xrange = 2000:2010)
  lptrns.post[i,] <- tmp$mean
  lptrns.postse[i,] <- tmp$se
  i = i+1
}

avg.dat$flagtrnstop <- ifelse(avg.dat$meantrns >= quantile(avg.dat$meantrns,.5,na.rm = T),1,0)
dat.trnstop <- avg.dat[which(avg.dat$flagtrnstop == 1),]
lptrnstop.pre <- array(NA,dim=c(length(unique(dat.trnstop$wdicode)),length(1980:2000)))
lptrnstop.prese <- array(NA,dim=c(length(unique(dat.trnstop$wdicode)),length(1980:2000)))
lptrnstop.post <- array(NA,dim=c(length(unique(dat.trnstop$wdicode)),length(2000:2010)))
lptrnstop.postse <- array(NA,dim=c(length(unique(dat.trnstop$wdicode)),length(2000:2010)))
i = 1
for(j in unique(dat.trnstop$wdicode)) {
  tmp <- loclpolCreate(dat = dat.trnstop[which(dat.trnstop$year <= 2000 & dat.trnstop$wdicode == j),],
                         xrange = 1980:2000)
  lptrnstop.pre[i,] <- tmp$mean
  lptrnstop.prese[i,] <- tmp$se
  tmp <- loclpolCreate(dat = dat.trnstop[which(dat.trnstop$year >= 2000 & dat.trnstop$wdicode == j),],
                       xrange = 2000:2010)
  lptrnstop.post[i,] <- tmp$mean
  lptrnstop.postse[i,] <- tmp$se
  i = i+1
}

pdf("./Figures/rdd-tests.pdf",width = 6,height = 6)
par(mar=c(4,6,3,4))
plot(avg.dat[which(avg.dat$wdicode=="USA"),"year"],
     avg.dat[which(avg.dat$wdicode=="USA"),"prmscale"],
     cex=.5,pch=19,col=rgb(0,0,0,.05),ylim=c(0.2,.55),
     xlab="Year",ylab="",xaxs='i',main="Discontinuity Checks",yaxt='n')
axis(4,at=seq(.2,.7,by=.1),labels=seq(.2,.7,by=.1),las=2,cex.axis=.8)
for(i in unique(avg.dat$wdicode)) {
  points(jitter(avg.dat[which(avg.dat$wdicode==i),"year"],amount = .5),
         avg.dat[which(avg.dat$wdicode==i),"prmscale"],
         col=rgb(0,0,0,.02),cex=.5,pch=19,jitter=.1)
}
abline(v=2000,lty=3)
mns.pre <- sapply(1:ncol(mainlocpol.pre), function(x) weighted.mean(mainlocpol.pre[,x],1/mainlocpol.prese[,x]))
ses.pre <- sapply(1:ncol(mainlocpol.prese), function(x) weighted.mean(mainlocpol.prese[,x],1/mainlocpol.prese[,x]))
mns.post <- sapply(1:ncol(mainlocpol.post), function(x) weighted.mean(mainlocpol.post[,x],1/mainlocpol.postse[,x]))
ses.post <- sapply(1:ncol(mainlocpol.postse), function(x) weighted.mean(mainlocpol.postse[,x],1/mainlocpol.postse[,x]))
lines(1980:2000,mns.pre,lty=1)
polygon(c(1980:2000,rev(1980:2000)),c(mns.pre+ses.pre,rev(mns.pre-ses.pre)),lty = 1,col=rgb(0,0,0,.1))
lines(2000:2010,mns.post,lty=1)
polygon(c(2000:2010,rev(2000:2010)),c(mns.post+ses.post,rev(mns.post-ses.post)),lty = 1,col=rgb(0,0,0,.1))
mtext(text = "Overall",side = 2,at = c(mns.pre[1]),las=2,cex=.8,line = 1)

mns.pre <- sapply(1:ncol(lplow.pre), function(x) weighted.mean(lplow.pre[,x],1/lplow.prese[,x]))
ses.pre <- sapply(1:ncol(lplow.prese), function(x) weighted.mean(lplow.prese[,x],1/lplow.prese[,x]))
mns.post <- sapply(1:ncol(lplow.post), function(x) weighted.mean(lplow.post[,x],1/lplow.postse[,x]))
ses.post <- sapply(1:ncol(lplow.postse), function(x) weighted.mean(lplow.postse[,x],1/lplow.postse[,x]))
lines(1980:2000,mns.pre,lty=2)
polygon(c(1980:2000,rev(1980:2000)),c(mns.pre+ses.pre,rev(mns.pre-ses.pre)),lty = 2,col=makeTransparent('#d9f0a3',120))
lines(2000:2010,mns.post,lty=2)
polygon(c(2000:2010,rev(2000:2010)),c(mns.post+ses.post,rev(mns.post-ses.post)),lty = 2,col=makeTransparent('#d9f0a3',120))
mtext(text = "Bottom Quartile\n1980 Enrollment",side = 2,at = c(mns.pre[1]),las=2,cex=.8,line = 1)

mns.pre <- sapply(1:ncol(lptrns.pre), function(x) weighted.mean(lptrns.pre[,x],1/lptrns.prese[,x]))
ses.pre <- sapply(1:ncol(lptrns.prese), function(x) weighted.mean(lptrns.prese[,x],1/lptrns.prese[,x]))
mns.post <- sapply(1:ncol(lptrns.post), function(x) weighted.mean(lptrns.post[,x],1/lptrns.postse[,x]))
ses.post <- sapply(1:ncol(lptrns.postse), function(x) weighted.mean(lptrns.postse[,x],1/lptrns.postse[,x]))
lines(1980:2000,mns.pre,lty=3)
polygon(c(1980:2000,rev(1980:2000)),c(mns.pre+ses.pre,rev(mns.pre-ses.pre)),lty = 3,col=makeTransparent('#fa9fb5',120))
lines(2000:2010,mns.post,lty=3)
polygon(c(2000:2010,rev(2000:2010)),c(mns.post+ses.post,rev(mns.post-ses.post)),lty = 3,col=makeTransparent('#fa9fb5',120))
mtext(text = "Bottom Quartile\nTransparency",side = 2,at = c(mns.pre[1]),las=2,cex=.8,line = 1)

mns.pre <- sapply(1:ncol(lptrnstop.pre), function(x) weighted.mean(lptrnstop.pre[,x],1/lptrnstop.prese[,x]))
ses.pre <- sapply(1:ncol(lptrnstop.prese), function(x) weighted.mean(lptrnstop.prese[,x],1/lptrnstop.prese[,x]))
mns.post <- sapply(1:ncol(lptrnstop.post), function(x) weighted.mean(lptrnstop.post[,x],1/lptrnstop.postse[,x]))
ses.post <- sapply(1:ncol(lptrnstop.postse), function(x) weighted.mean(lptrnstop.postse[,x],1/lptrnstop.postse[,x]))
lines(1980:2000,mns.pre,lty=3)
polygon(c(1980:2000,rev(1980:2000)),c(mns.pre+ses.pre,rev(mns.pre-ses.pre)),lty = 3,col=makeTransparent('#ae017e',120))
lines(2000:2010,mns.post,lty=3)
polygon(c(2000:2010,rev(2000:2010)),c(mns.post+ses.post,rev(mns.post-ses.post)),lty = 3,col=makeTransparent('#ae017e',120))
mtext(text = "Top Quartile\nTransparency",side = 2,at = c(mns.pre[1]),las=2,cex=.8,line = 1)

mns.pre <- sapply(1:ncol(lphigh.pre), function(x) weighted.mean(lphigh.pre[,x],1/lphigh.prese[,x]))
ses.pre <- sapply(1:ncol(lphigh.prese), function(x) weighted.mean(lphigh.prese[,x],1/lphigh.prese[,x]))
mns.post <- sapply(1:ncol(lphigh.post), function(x) weighted.mean(lphigh.post[,x],1/lphigh.postse[,x]))
ses.post <- sapply(1:ncol(lphigh.postse), function(x) weighted.mean(lphigh.postse[,x],1/lphigh.postse[,x]))
lines(1980:2000,mns.pre,lty=2)
polygon(c(1980:2000,rev(1980:2000)),c(mns.pre+ses.pre,rev(mns.pre-ses.pre)),lty = 2,col=makeTransparent('#41ab5d',120))
lines(2000:2010,mns.post,lty=2)
polygon(c(2000:2010,rev(2000:2010)),c(mns.post+ses.post,rev(mns.post-ses.post)),lty = 2,col=makeTransparent('#41ab5d',120))
mtext(text = "Top Quartile\n1980 Enrollment",side = 2,at = c(mns.pre[1]),las=2,cex=.8,line = 1)
dev.off()




# Sensitivity analyses
genConfound <- function(test.dat,alpha,delta,dep,treat) {
  e <- rnorm(nrow(test.dat),0,1)
  U <- alpha * test.dat[,paste(dep,collapse="")] + delta * test.dat[,paste(treat,collapse="")] + e
  return(U)
}



alphas <- rnorm(500,0,4)
deltas <- rnorm(500,0,4)
results <- NULL
for (i in 1:length(alphas)) {
  U <- genConfound(test.dat = ECM.am[[1]],alphas[i],deltas[i],"beta","mdg")
  cortreat <- cor(U,ECM.am[[1]]$mdg,use = "complete.obs")
  corout <- cor(U,ECM.am[[1]]$beta,use = "complete.obs")
  sens <- mi.extract(paste("beta ~ mdg*(trans + dem) + log.gdppc.2000 + U +
                             scale(log((AID_Total_mean)+1)) + 
                   scale(log((AID_Primary_education_mean)+1)) + 
                   scale(log((AID_Secondary_education_mean)+1)) + (1|wdicode)",sep=""),ECM.am)[[1]]
  estTE <- sens["mdg",1]
  orig <- mi.extract(paste("beta ~ mdg*(trans + dem) + log.gdppc.2000 + 
                             scale(log((AID_Total_mean)+1)) + 
                   scale(log((AID_Primary_education_mean)+1)) + 
                   scale(log((AID_Secondary_education_mean)+1)) + (1|wdicode)",sep=""),ECM.am)[[1]]
  origTE <- orig["mdg",1]
  origTEse <- orig["mdg",2]
  diffTE <- estTE - origTE
  names(estTE) <- NULL
  res <- c(cortreat,corout,estTE,origTE,origTEse,diffTE)
  results<- rbind(results,res)
  cat(paste0(i,"\n"))
}

colnames(results) <- c("cortreat","corout","estTE","origTE","origTEse","diffTE")

color <- ifelse(results[, "estTE"] > results[,"origTE"] + results[,"origTEse"]*2 | 
                  results[, "estTE"] < results[,"origTE"] - results[,"origTEse"]*2, rgb(0,0,0,alpha = 120,maxColorValue = 255), NA)
fill <- ifelse(results[, "estTE"] > results[,"origTE"] + results[,"origTEse"]*2 | 
                 results[, "estTE"] < results[,"origTE"] - results[,"origTEse"]*2, 19, NA)
color <- ifelse(is.na(color), rgb(0,0,0,alpha = 60,maxColorValue = 255), color)
fill <- ifelse(is.na(fill), 1, fill)

lines <- c(paste0("Sensitivity Analysis:",
           bquote(beta~Substition ~ and ~ MDG ~ Adoption)))
pdf("./Figures/sensitivity-analysis-mdg.pdf",width = 6,height = 6)
plot(results[, "cortreat"], results[, "corout"], col = color, pch=fill,bg=color,  cex=.7,xlab = "Correlation with MDG", 
     ylab = bquote(Correlation~with~beta~Substitution), xlim = c(-1, 1), ylim = c(-1, 1),main="Sensitivity Analysis:\nSubstitution vs. MDG Adoption")
cortreat <- with(ECM.am[[1]], cor(get("log.gdppc.2000"), ECM.am[[1]]$mdg,use = "complete.obs"))
corout <- with(ECM.am[[1]], cor(get("log.gdppc.2000"), ECM.am[[1]]$beta,use = "complete.obs"))
points(cortreat, corout, pch = "+", col = "black")
text(cortreat,corout,labels="Log GDPpc",pos=1,cex=.75)

abline(v = 0, col = "grey", lty = 3)
abline(h = 0, col = "grey", lty = 3)
legend("bottomleft",
       legend=c("outside 95% CI",
                "within 95% CI",
                "Covariate Correlations"),
       pch=c(19,1,3),col=c(rgb(0,0,0,alpha = 120,maxColorValue = 255),
                           rgb(0,0,0,alpha = 60,maxColorValue = 255)
                           ,"black"),cex=.8)
dev.off()

alphas <- rnorm(500,0,4)
deltas <- rnorm(500,0,4)
results <- NULL
for (i in 1:length(alphas)) {
  U <- genConfound(test.dat = ECM.am[[1]],alphas[i],deltas[i],"beta","dem")
  cortreat <- cor(U,ECM.am[[1]]$dem,use = "complete.obs")
  corout <- cor(U,ECM.am[[1]]$beta,use = "complete.obs")
  sens <- mi.extract(paste("beta ~ mdg*(trans + dem) + log.gdppc.2000 + U +
                           scale(log((AID_Total_mean)+1)) + 
                           scale(log((AID_Primary_education_mean)+1)) + 
                           scale(log((AID_Secondary_education_mean)+1)) + (1|wdicode)",sep=""),ECM.am)[[1]]
  estTE <- sens["mdg:dem",1]
  orig <- mi.extract(paste("beta ~ mdg*(trans + dem) + log.gdppc.2000 + 
                           scale(log((AID_Total_mean)+1)) + 
                           scale(log((AID_Primary_education_mean)+1)) + 
                           scale(log((AID_Secondary_education_mean)+1)) + (1|wdicode)",sep=""),ECM.am)[[1]]
  origTE <- orig["mdg:dem",1]
  origTEse <- orig["mdg:dem",2]
  diffTE <- estTE - origTE
  names(estTE) <- NULL
  res <- c(cortreat,corout,estTE,origTE,origTEse,diffTE)
  results<- rbind(results,res)
  cat(paste0(i,"\n"))
}

colnames(results) <- c("cortreat","corout","estTE","origTE","origTEse","diffTE")

color <- ifelse(results[, "estTE"] > results[,"origTE"] + results[,"origTEse"]*2 | 
                  results[, "estTE"] < results[,"origTE"] - results[,"origTEse"]*2, rgb(0,0,0,alpha = 120,maxColorValue = 255), NA)
fill <- ifelse(results[, "estTE"] > results[,"origTE"] + results[,"origTEse"]*2 |
                 results[, "estTE"] < results[,"origTE"] - results[,"origTEse"]*2, 19, NA)
color <- ifelse(is.na(color), rgb(0,0,0,alpha = 60,maxColorValue = 255), color)
fill <- ifelse(is.na(fill), 1, fill)

pdf("./Figures/sensitivity-analysis-dem.pdf",width = 6,height = 6)
plot(results[, "cortreat"], results[, "corout"], col = color, pch=fill,bg=color,  cex=.7,xlab = "Correlation with Democracy", 
     ylab = bquote(Correlation~with~beta~Substitution), xlim = c(-1, 1), ylim = c(-1, 1),main="Sensitivity Analysis:\nSubstitution vs. Democracy")

cortreat <- with(ECM.am[[1]], cor(get("log.gdppc.2000"), ECM.am[[1]]$dem,use = "complete.obs"))
corout <- with(ECM.am[[1]], cor(get("log.gdppc.2000"), ECM.am[[1]]$beta,use = "complete.obs"))
points(cortreat, corout, pch = "+", col = "black")
text(cortreat,corout,labels="Log GDPpc",pos=1,cex=.75)

abline(v = 0, col = "grey", lty = 3)
abline(h = 0, col = "grey", lty = 3)
legend("bottomleft",
       legend=c("outside 95% CI",
                "within 95% CI",
                "Covariate Correlations"),
       pch=c(19,1,3),col=c(rgb(0,0,0,alpha = 120,maxColorValue = 255),
                           rgb(0,0,0,alpha = 60,maxColorValue = 255)
                           ,"black"),cex=.8)
dev.off()


alphas <- rnorm(500,0,4)
deltas <- rnorm(500,0,4)
results <- NULL
for (i in 1:length(alphas)) {
  U <- genConfound(test.dat = ECM.am[[1]],alphas[i],deltas[i],"beta","trans")
  cortreat <- cor(U,ECM.am[[1]]$trans,use = "complete.obs")
  corout <- cor(U,ECM.am[[1]]$beta,use = "complete.obs")
  sens <- mi.extract(paste("beta ~ mdg*(trans + dem) + log.gdppc.2000 + U +
                           scale(log((AID_Total_mean)+1)) + 
                           scale(log((AID_Primary_education_mean)+1)) + 
                           scale(log((AID_Secondary_education_mean)+1)) + (1|wdicode)",sep=""),ECM.am)[[1]]
  estTE <- sens["mdg:trans",1]
  orig <- mi.extract(paste("beta ~ mdg*(trans + dem) + log.gdppc.2000 + 
                           scale(log((AID_Total_mean)+1)) + 
                           scale(log((AID_Primary_education_mean)+1)) + 
                           scale(log((AID_Secondary_education_mean)+1)) + (1|wdicode)",sep=""),ECM.am)[[1]]
  origTE <- orig["mdg:trans",1]
  origTEse <- orig["mdg:trans",2]
  diffTE <- estTE - origTE
  names(estTE) <- NULL
  res <- c(cortreat,corout,estTE,origTE,origTEse,diffTE)
  results<- rbind(results,res)
  cat(paste0(i,"\n"))
}

colnames(results) <- c("cortreat","corout","estTE","origTE","origTEse","diffTE")

color <- ifelse(results[, "estTE"] > results[,"origTE"] + results[,"origTEse"]*2 | 
                  results[, "estTE"] < results[,"origTE"] - results[,"origTEse"]*2, rgb(0,0,0,alpha = 120,maxColorValue = 255), NA)
fill <- ifelse(results[, "estTE"] > results[,"origTE"] + results[,"origTEse"]*2 | 
                 results[, "estTE"] < results[,"origTE"] - results[,"origTEse"]*2, 19, NA)
color <- ifelse(is.na(color), rgb(0,0,0,alpha = 60,maxColorValue = 255), color)
fill <- ifelse(is.na(fill), 1, fill)


pdf("./Figures/sensitivity-analysis-trans.pdf",width = 6,height = 6)
plot(results[, "cortreat"], results[, "corout"], col = color, pch=fill,bg=color,  
     cex=.7,xlab = "Correlation with Transparency", ylab = bquote(Correlation~with~beta~Substitution), 
     xlim = c(-1, 1), ylim = c(-1, 1),main="Sensitivity Analysis:\nSubstitution vs. Transparecy")

cortreat <- with(ECM.am[[1]], cor(get("log.gdppc.2000"), ECM.am[[1]]$trans,use = "complete.obs"))
corout <- with(ECM.am[[1]], cor(get("log.gdppc.2000"), ECM.am[[1]]$beta,use = "complete.obs"))
points(cortreat, corout, pch = "+", col = "black")
text(cortreat,corout,labels="Log GDPpc",pos=1,cex=.75)

abline(v = 0, col = "grey", lty = 3)
abline(h = 0, col = "grey", lty = 3)
legend("bottomleft",
       legend=c("outside 95% CI",
                "within 95% CI",
                "Covariate Correlations"),
       pch=c(19,1,3),col=c(rgb(0,0,0,alpha = 120,maxColorValue = 255),
                              rgb(0,0,0,alpha = 60,maxColorValue = 255)
                              ,"black"),cex=.8)
dev.off()



# BCP Analysis
source("bcp.R")
cntries <- unique(dat.am$imputations$imp1$wdicode)

# -------------------------------------------------------------------------

# Setting the priors for the simple regression
pmu <- rep(0,4) # prior on coefficients
pvb <- diag(rep(100,4)) # prior on covariance matrix for coefs
pa <- .001 # Prior on dof
pb <- .001 # Prior on SS


# -------------------------------------------------------------------------

# Running the regression on each country and saving the mode of theta
bcp.dat <- as.data.frame(dat.am$imputations$imp2 %>% dplyr::select(year,primraw,secraw,wdicode))

modes <- sapply(cntries,function(x) sscp(cbind(1,bcp.dat[which(bcp.dat$wdicode == x),"secraw"]),
                                         bcp.dat[which(bcp.dat$wdicode == x),"primraw"],
                                         pmu,pvb,pa,pb,bayes=T)[[4]])
probs <- sapply(cntries,function(x) sscp(cbind(1,bcp.dat[which(bcp.dat$wdicode == x),"secraw"]),
                                         bcp.dat[which(bcp.dat$wdicode == x),"primraw"],
                                         pmu,pvb,pa,pb,bayes=T)[[2]][,1])
years <- sapply(cntries,function(x) sscp(cbind(1,bcp.dat[which(bcp.dat$wdicode == x),"secraw"]),
                                         bcp.dat[which(bcp.dat$wdicode == x),"primraw"],
                                         pmu,pvb,pa,pb,bayes=T)[[1]])
cntries.low <- unique(bcp.dat[which(bcp.dat$primraw < 40),"wdicode"])
modes.low <- modes[which(cntries %in% cntries.low)]

pdf("./Figures/bcp-new.pdf",width=7,height=5)
plot(density(modes.low,adjust = .8),lty=2,xlab="Year",xaxt='n',ylab="Density of Modal Theta",main="",
     xlim=c(-1,32))
axis(1,at=1:31,labels=1980:2010,cex.axis=.8)
abline(v=21,lty=1)
polygon(density(modes,adjust = .8),col=rgb(0,0,0,.2),border="black")
polygon(density(modes.low,adjust = .8),col=rgb(1,1,1,.5),border="black",lty=2)
legend("topleft",legend=c("Full Sample","Low Primary"),lty=c(1,2),
       col=c("black","black"),cex=.7)
dev.off()
